@@ -140,10 +140,13 @@ sub get_rdo_folder_from_path {
 	return $folders[-1]{rdo_folder};
 }
 
+__PACKAGE__->meta->make_immutable;
+1;
+
 =head1 NAME
 
 Email::PST::Win32 - Writing and updating PST files using
-Outlook Redemption on Windows.
+Outlook Redemption on Windows
 
 =head1 SYNOPSIS
 
@@ -195,9 +198,13 @@ L<http://www.dimastr.com/redemption/> (Outlook Redemption)
 
 John Wang <johncwang@gmail.com>, L<http://johnwang.com> 
 
-=head1 COPYRIGHT AND LICENSE (The MIT License)
+=head1 COPYRIGHT
 
-Copyright (c) 2009-2015 John Wang
+Copyright (c) 2009-2015 John Wang E<lt>johncwang@gmail.com>E<gt>.
+
+This software is released under the MIT license cited below.
+
+=head2 The "MIT" License
 
 Permission is hereby granted, free of charge, to any person obtaining
 a copy of this software and associated documentation files (the
@@ -219,6 +226,3 @@ OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 =cut
-
-__PACKAGE__->meta->make_immutable;
-1;
\ No newline at end of file
